pub enum HandoverMethod {
Pickup,
Dropoff,
}Expand description
HandoverMethod : Identifies the method by which a seller will hand a package over to Amazon Logistics. Identifies the method by which a seller will hand a package over to Amazon Logistics.
Variants
Pickup
Dropoff